
************ FUNCION DE PRODUCCION************

********Import datos excel******************
insheet using e:/fproduccion.csv, delimiter(;)
save e:/fproduccion, replace

***********Usar fichero dta******************

clear 

use e:/fproduccion.dta

describe 
summarize
summarize lngdp, detail

*******Programming******

**** Looping while

local i =1
	while `i' < 20 	{
	display `i'
	egen meanyear=mean(year[`i'])
	display as text "average year = " as result meanyear
	drop meanyear
	local i = `i' + 1
	} 
end

local i =1970
	while `i' < 1971 	{
	display `i'
	egen meanlncapital=mean(lncapital) if year==`i'
	display as text "average annual lncapital = " as result meanlncapital
	drop meanlncapital
	local i = `i' + 1
	} 
end

local i =1970
	while `i' < 1979 	{
	display `i'
	twoway (scatter lncapital region ) if year==`i'
	local i = `i' + 1
	} 

	* This is equivalent to.....
	twoway (scatter lncapital region ) if year==1970
	twoway (scatter lncapital region ) if year==1971
	twoway (scatter lncapital region ) if year==1972
	twoway (scatter lncapital region ) if year==1973
	twoway (scatter lncapital region ) if year==1974
	twoway (scatter lncapital region ) if year==1975
	twoway (scatter lncapital region ) if year==1976
	twoway (scatter lncapital region ) if year==1977
	twoway (scatter lncapital region ) if year==1978	

**** Looping foreach

foreach var of varlist region-lncapital  {
	quietly summarize `var'
	summarize `var' if `var' > r(mean)
	} 
	 
end

**** Looping forvalues

	gen x1=region
	gen x2=lnlabour
	gen x3=lncapital
	
	forvalues num=2/3 {
	summarize x`num'
	egen meanx=mean(x`num') if (x`num'>=13 & x`num'<=15)
	display as text "average value = " as result meanx
	drop meanx
	display "number of observations between 13 and 15: "
	count if (x`num'>=13 & x`num'<=15)
	}
end

* List the number 1-5, stepping by 1

	forvalues i = 10(-2)1{
	display `i'
	}

end

**********  GRAPHS ****************
histogram lngdp
graph box lngdp
twoway (scatter lngdp lncapital)
twoway(lfit lngdp lncapital)

********** OLS  ********************************

regress  lngdp time lnlabour lncapital, robust
ereturn list

predict produccion1, xb
predict residuo1, r


******** Time series analysis********

clear 
use e:/gdp.dta

tsset time
twoway (tsline gdp)

generate gdp_1=gdp[_n-1]
generate dgdp=gdp-gdp_1
twoway (tsline dgdp)

generate lgdp=ln( gdp)
twoway (tsline lgdp)

generate dlgdp=lgdp-lgdp[_n-1]
twoway (tsline dlgdp)

dfuller gdp, lags(0)
dfuller lgdp, lags(0)
dfuller dlgdp , lags(0)

tsset trend
hprescott gdp, stub(hp)
twoway(tsline hp_gdp_1)

ac dlgdp
pac dlgdp
arima lgdp, arima(2,1,0)

********* PANEL DATA MODEL***********

clear 

use e:/fproduccion.dta

tsset  region year

xtdescribe
xtsum

xtreg  lngdp time lnlabour lncapital,fe

estimates store fixed

xtreg  lngdp time lnlabour lncapital,re

hausman fixed

xtreg  lngdp time lnlabour lncapital,fe

predict produccion2, xb
predict residuos,e
predict efectos,u

xtregar  lngdp time lnlabour lncapital,fe lbi
xtregar  lngdp time lnlabour lncapital,fe twostep
xtregar  lngdp time lnlabour lncapital,re lbi

******** PANEL DATA MODEL WITH INSTRUMENTAL VARIABLE ********

clear 

use e:/fproduccionvi.dta

tsset  region year

xtivreg lngdp time lnlabour (lncapital=lncapitaliv),fe
estimates store fixed
xtivreg lngdp time lnlabour (lncapital=lncapitaliv),re
hausman fixed

xtivreg lngdp time lnlabour (lncapital=lncapitaliv),fe



******* DYNAMIC MODEL ******************************
clear 

use e:/fproduccion.dta

tsset  region year

xtabond  lngdp time lnlabour lncapital, endog(lncapital)
xtabond  lngdp time lnlabour lncapital, endog(lncapital) twostep 
estat abond
estat sargan

xtdpd L(0/2).lngdp time lnlabour lncapital, dgmmiv(lngdp) twostep
estat abond
estat sargan

xtdpdsys  lngdp time lnlabour lncapital, endog(lncapital) twostep 
estat abond
estat sargan


************DISCRETE CHOICE MODELS*************************
clear 

use e:/fproduccion.dta

tsset  region year

summarize lngdp, detail
generate d=1 if lngdp>=8.723713
replace d=0 if d==.

logit d time lnlabour lncapital
logistic d time lnlabour lncapital
probit d time lnlabour lncapital

ivprobit d time lnlabour (lncapital=L.lncapital)
ivprobit d time lnlabour (lncapital=L.lncapital), twostep

xtlogit dtime time lnlabour lncapital,fe
estimates store fixed
xtlogit dtime time lnlabour lncapital,re
hausman fixed

xtlogit dtime time lnlabour lncapital,fe
xtlogit dtime time lnlabour lncapital,pa

xtprobit dtime time lnlabour lncapital, re
xtprobit dtime time lnlabour lncapital, pa
